



# Noah's Sentiment Classifier

A simple ensemble sentiment classifier using TextBlob, VADER, and Transformers (including Roberta).

## Installation

```bash
pip install noahs-sentiment-classifier
```